@@ -1,7 +1,7 @@
 package TestClass;
 
 use Moose;
-use Pinto::Types qw(File Dir URI IO AuthorID);
+use Pinto::Types qw(File Dir URI IO AuthorID Vers);
 
 #-----------------------------------------------------------------------------
 
@@ -35,6 +35,12 @@ has author => (
     coerce => 1,
 );
 
+has version => (
+    is  => 'rw',
+    isa => Vers,
+    coerce => 1,
+);
+
 #-----------------------------------------------------------------------------
 
 1;
